package project

import (
	"doc-service/common/log"
	models "doc-service/modes"
	"doc-service/modes/db"
	"errors"
)

const sqlSaveOrUpdate = `
insert into doc_server_project ( 
	project_name, source_type, target_type, source_url, target_url, task_id,app_id,status,created_at
) value (
	?, ?, ?, ?, ?, ?,?,?,?
)
on duplicate key update task_id = values(task_id), created_at = values(created_at)
`

// 保存或者更新数据
func SaveOrUpdate(project *db.DocServerProject) (error, int) {
	if nil == project {
		return errors.New("project 不能为空"), 0
	}

	stmt, err := models.MysqlDB.Prepare(sqlSaveOrUpdate)

	if nil != err {
		log.Error("%+v", err)
		return err, 0
	}

	result, err1 := stmt.Exec(
		//project.Id,
		project.ProjectName,
		project.SourceType,
		project.TargetType,
		project.SourceUrl,
		project.TargetUrl,
		project.TaskId,
		project.AppId,
		project.Status,
		project.CreatedAt,
	)

	if nil != err1 {
		log.Error("%+v", err1)
		return err1, 0
	}

	rowId, err2 := result.LastInsertId()

	if nil != err2 {
		log.Error("%+v", err2)
		return err2, 0
	}

	project.Id = int(rowId)
	return nil, project.Id
}
